@@ -44,7 +44,6 @@
 class cgfb 
 {
   private static $_fb;
-  private static $_fbsession;
   private static $_fbuid;
   private static $_fbme;
 
@@ -54,13 +53,11 @@ class cgfb
   {
     if( is_object(self::$_fb) ) return;
     
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $appid = $mod->GetPreference('fb_appid');
     $appsecret = $mod->GetPreference('fb_appsecret');
 
     self::$_fb = new CGFacebook(array('appId'=>$appid,'secret'=>$appsecret,'cookie'=>true));
-    //self::$_fb = new CGFacebook(array('appId'=>$appid,'secret'=>$appsecret));
-    self::$_fbsession = self::$_fb->getSession();
   }
 
 
@@ -69,7 +66,7 @@ class cgfb
    */
   public static function appid()
   {
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $appid = $mod->GetPreference('fb_appid');
     return $appid;
   }
@@ -82,17 +79,14 @@ class cgfb
   {
     self::init();
 
-    if( is_null(self::$_fbuid) )
-      {
-	try 
-	  {
-	    self::$_fbuid = self::$_fb->getUser();
-	  }
-        catch( FacebookApiException $e ) 
-	  {
-	    // nothing here, yet
-	  }
+    if( is_null(self::$_fbuid) ) {
+      try {
+	self::$_fbuid = self::$_fb->getUser();
       }
+      catch( FacebookApiException $e ) {
+	// nothing here, yet
+      }
+    }
 
     return self::$_fbuid;
   }
@@ -100,14 +94,21 @@ class cgfb
 
   /**
    * Get a login url for the facebook user
+   * This function accepts a special associative array of parameters
+   * scope: comma delimited list of facebook extended permissions.  If not specified, module preferences will be used
+   * client_id: The app id.  if not specified, the module preference will be used.
+   * redirect_url: the URL to redirect to after login is complete.  If not specified, the current url will be used.
+   * extra_params: Extra parameters to add to the redirect url.
+   *
+   * @params associative array.
    */
-  public static function get_login_url()
+  public static function get_login_url($parms = null)
   {
     if( self::uid() ) return;
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $perms = $mod->GetPreference('fb_perms');
-    $parms = array();
-    if( $perms ) $parms['req_perms'] = $perms;
+    if( !is_array($parms) ) $parms = array();
+    if( $perms ) $parms['scope'] = $perms;
     return self::$_fb->getLoginUrl($parms);
   }
 
@@ -115,13 +116,22 @@ class cgfb
   /**
    * Get a logout url for the facebook user
    */
-  public static function get_logout_url()
+  public static function get_logout_url($params = array())
   {
     if( !self::uid() ) return;
-    return self::$_fb->getLogOutUrl();
+    return self::$_fb->getLogOutUrl($params);
   }
 
 
+  /**
+   * Destroy session information
+   */
+  public static function destroy_session()
+  {
+    if( !self::uid() ) return;
+    return self::$_fb->destroySession();
+  }
+
   /**
    * Perform a facebook API request using the user access token.
    */
@@ -130,19 +140,12 @@ class cgfb
     if( !self::uid() ) return;
     if( !$call ) return;
     if( !is_string($call) ) return;
-    try
-      {
-	$res = self::$_fb->api($call,$method,$params);
-	if( is_array($res) && count(array_keys($res)) == 1 && isset($res['data']) )
-	  {
-	    $res = $res['data'];
-	  }
-	return $res;
-      }
-    catch( FacebookApiException $e ) 
-      {
-	// nothing here, yet
-      }
+
+    $res = self::$_fb->api($call,$method,$params);
+    if( is_array($res) && count(array_keys($res)) == 1 && isset($res['data']) ) {
+      $res = $res['data'];
+    }
+    return $res;
   }
 
 
@@ -154,15 +157,13 @@ class cgfb
     if( !self::uid() ) return;
     if( !is_array($data) ) return;
 
-    try
-      {
-	$res = self::$_fb->api($data);
-	return $res;
-      }
-    catch( FacebookApiException $e ) 
-      {
-	// nothing here, yet
-      }
+    try {
+      $res = self::$_fb->api($data);
+      return $res;
+    }
+    catch( FacebookApiException $e ) {
+      // nothing here, yet
+    }
   }
   
   /**
@@ -172,18 +173,12 @@ class cgfb
   {
     if( !$call ) return;
     if( !is_string($call) ) return;
+    self::init();
 
-    try
-      {
-	self::$_fb->enableAppToken();
-	$res = self::$_fb->api($call,$method,$params);
-	self::$_fb->enableAppToken(FALSE);
-	return $res;
-      }
-    catch( FacebookApiException $e ) 
-      {
-	// nothing here, yet
-      }
+    self::$_fb->enableAppToken();
+    $res = self::$_fb->api($call,$method,$params);
+    self::$_fb->enableAppToken(FALSE);
+    return $res;
   }
 
 
@@ -194,11 +189,7 @@ class cgfb
   {
     self::init();
 
-    if( is_null(self::$_fbme) )
-      {
-	self::$_fbme = self::api('/me');
-      }
-
+    if( is_null(self::$_fbme) ) self::$_fbme = self::api('/me');
     return self::$_fbme;
   }
 
@@ -219,28 +210,30 @@ class cgfb
     // get the args, and check for too many... only 5 queries
     $args = func_get_args();
     if( is_array($args[0]) && count($args) > 1 ) return;
-    if( is_array($args[0]) )
-      {
-	$args = $args[0];
-      }
+    if( is_array($args[0]) ) {
+      $args = $args[0];
+    }
     if( count($args) > 5 ) return;
 
     // okay, maximum of 5 queries.. aint that nice.
     $q = array();
-    for( $i = 0; $i < count($args); $i++ )
-      {
-	$q[] = '"'.$k.'":"'.$v.'"';
-      }
-    $tmp = array('method'=>'fql.multiquery',
-		 'queries'=>$q);
+    for( $i = 0; $i < count($args); $i++ ) {
+      $q[] = '"'.$k.'":"'.$v.'"';
+    }
+    $tmp = array('method'=>'fql.multiquery','queries'=>$q);
     $res = self::rest($tmp);
 
     return $res;
   }
-				  
+
+  public static function getExtendedAccessToken()
+  {
+    self::$_fb->setExtendedAccessToken();
+    return self::$_fb->getAccessToken();
+  }
 } // end of class
 
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
