@@ -60,10 +60,9 @@ class cgfb_og_smarty
     if( !$key ) return;
 
     $data = array();
-    if( cge_tmpdata::exists('cgfb_og') )
-      {
-	$data = cge_tmpdata::get('cgfb_og');
-      }
+    if( cge_tmpdata::exists('cgfb_og') ) {
+      $data = cge_tmpdata::get('cgfb_og');
+    }
     $data[$key] = $value;
     cge_tmpdata::set('cgfb_og',$data);
   }
@@ -81,64 +80,57 @@ class cgfb_og_smarty
 
   public static function og_title($params,&$smarty)
   {
-    if( isset($params['title']) )
-      {
-	self::og_setvalue('og:title',trim($params['title']));
-      }
+    if( isset($params['title']) ) {
+      self::og_setvalue('og:title',trim($params['title']));
+    }
   }
 
 
   public static function og_type($params,&$smarty)
   {
-    if( isset($params['type']) )
-      {
-	self::og_setvalue('og:type',trim($params['type']));
-      }
+    if( isset($params['type']) ) {
+      self::og_setvalue('og:type',trim($params['type']));
+    }
   }
 
 
   public static function og_url($params,&$smarty)
   {
-    if( isset($params['url']) )
-      {
-	self::og_setvalue('og:url',trim($params['url']));
-      }
+    if( isset($params['url']) ) {
+      self::og_setvalue('og:url',trim($params['url']));
+    }
   }
 
 
   public static function og_image($params,&$smarty)
   {
-    if( isset($params['image']) )
-      {
-	self::og_setvalue('og:image',trim($params['image']));
-      }
+    if( isset($params['image']) ) {
+      self::og_setvalue('og:image',trim($params['image']));
+    }
   }
 
 
   public static function og_sitename($params,&$smarty)
   {
-    if( isset($params['sitename']) )
-      {
-	self::og_setvalue('og:site_name',trim($params['sitename']));
-      }
+    if( isset($params['sitename']) ) {
+      self::og_setvalue('og:site_name',trim($params['sitename']));
+    }
   }
 
 
   public static function og_desc($params,&$smarty)
   {
-    if( isset($params['desc']) )
-      {
-	self::og_setvalue('og:description',trim($params['desc']));
-      }
+    if( isset($params['desc']) ) {
+      self::og_setvalue('og:description',trim($params['desc']));
+    }
   }
 
 
   public static function og_admins($params,&$smarty)
   {
-    if( isset($params['admins']) )
-      {
-	self::og_setvalue('fb:admins',trim($params['admins']));
-      }
+    if( isset($params['admins']) ) {
+      self::og_setvalue('fb:admins',trim($params['admins']));
+    }
   }
 
 
@@ -149,25 +141,22 @@ class cgfb_og_smarty
     $tmp = cgfb::appid();
     if( $tmp ) $data['fb:app_id'] = $tmp;
 
-    if( !isset($data['og:site_name']) )
-      {
-	$data['og:site_name'] = get_site_preference('sitenae','CMSMS Site');
-      }
+    if( !isset($data['og:site_name']) ) {
+      $data['og:site_name'] = get_site_preference('sitename','CMSMS Site');
+    }
 
     $output = '';
-    foreach( $data as $key => $value )
-      {
-	$value = trim($value);
-	if( empty($value) ) continue;
-	$output .= '<meta property="'.$key.'" content="'.$value.'"/>';
-      }
+    foreach( $data as $key => $value ) {
+      $value = trim($value);
+      if( empty($value) ) continue;
+      $output .= '<meta property="'.$key.'" content="'.$value.'"/>';
+    }
 
     // done.
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$output);
+      return;
+    }
 
     return $output;
   }
@@ -177,4 +166,4 @@ class cgfb_og_smarty
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
