@@ -41,7 +41,6 @@ class cgfb_post
   private $_actions = array();
   private $_attachment;
   private $_keys = array('to','message');
-
   
   public function __construct($msg,$to='me')
   {
@@ -49,64 +48,44 @@ class cgfb_post
     if( $to ) $this->_data['to'] = $to;
   }
 
-
   public function __get($key)
   {
-    if( !in_array($key,$this->_keys) )
-      {
-	throw new Exception('Attempt to retrieve invalid value of post object');
-      }
-
-    if( !isset($this->_data[$key]) )
-      {
-	return;
-      }
+    if( !in_array($key,$this->_keys) ) throw new Exception('Attempt to retrieve invalid value of post object');
+    if( !isset($this->_data[$key]) ) return;
 
     return $this->_data[$key];
   }
 
-
   public function __set($key,$value)
   {
-    if( !in_array($key,$this->_keys) )
-      {
-	throw new Exception('Attempt to set invalid value of post object');
-      }
+    if( !in_array($key,$this->_keys) ) throw new Exception('Attempt to set invalid value of post object');
 
     $this->_data[$key] = $value;
   }
 
-
   public function add_action($name,$link)
   {
-    if( !$name || !$link )
-      {
-	return;
-      }
+    if( !$name || !$link ) return;
     if( count($this->_actions) >= 3 ) return;
 
     $this->_actions[] = array('text'=>$name,'href'=>$link);
   }
 
-
   public function set_attachment(cgfb_post_attachment $attachment)
   {
     $this->_attachment = $attachment;
   }
 
-
   public function to_array()
   {
     $output = $this->_data;
     $output['target_id'] = ($this->to == 'me')?cgfb::uid():$this->to;
-    if( count($this->_actions) )
-      {
-	$output['action_links'] = $this->_actions;
-      }
-    if( is_object($this->_attachment) )
-      {
-	$output['attachment'] = $this->_attachment->to_array();
-      }
+    if( count($this->_actions) ) {
+      $output['action_links'] = $this->_actions;
+    }
+    if( is_object($this->_attachment) ) {
+      $output['attachment'] = $this->_attachment->to_array();
+    }
     return $output;
   }
 } // class
@@ -114,4 +93,4 @@ class cgfb_post
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
