@@ -35,7 +35,7 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-class cgfb_post_attachment
+final class cgfb_post_attachment
 {
   private $_keys = array('name','href','caption','description','comments_xid');
   private $_data = array();
@@ -45,10 +45,9 @@ class cgfb_post_attachment
 
   public function __construct($name,$href,$caption = '',$description = '')
   {
-    if( !$name || !$href ) 
-      {
-	throw new Exception('Attempt to create invalid attachment object');
-      }
+    if( !$name || !$href ) {
+      throw new Exception('Attempt to create invalid attachment object');
+    }
 
     $this->name = $name;
     $this->href = $href;
@@ -59,10 +58,9 @@ class cgfb_post_attachment
 
   public function __get($key)
   {
-    if( !in_array($key,$this->_keys) )
-      {
-	throw new Exception('Attempt to retrieve invalid value from post_attachment object');
-      }
+    if( !in_array($key,$this->_keys) ) {
+      throw new Exception('Attempt to retrieve invalid value from post_attachment object');
+    }
 
     if( !isset($this->_data[$key]) ) return;
     return $this->_data[$key];
@@ -71,21 +69,18 @@ class cgfb_post_attachment
 
   public function __set($key,$value)
   {
-    if( !in_array($key,$this->_keys) )
-      {
-	throw new Exception('Attempt to modify invalid value from post_attachment object');
-      }
+    if( !in_array($key,$this->_keys) ) {
+      throw new Exception('Attempt to modify invalid value from post_attachment object');
+    }
     
-    switch( $key )
-      {
-      case 'media':
-	$value = strtolower($value);
-	if( $value != 'image' && $value != 'flash' && $value != 'music' )
-	  {
-	    throw new Exception('Attempt to modify attachment object with invalid value');
-	  }
-	break;
+    switch( $key ) {
+    case 'media':
+      $value = strtolower($value);
+      if( $value != 'image' && $value != 'flash' && $value != 'music' ) {
+	throw new Exception('Attempt to modify attachment object with invalid value');
       }
+      break;
+    }
 
     $this->$key = $value;
   }
@@ -93,15 +88,13 @@ class cgfb_post_attachment
 
   public function add_media($type,$src,$href)
   {
-    if( ($type != 'image' && $type != 'flash' && $type != 'music') || !$src || !$href )
-      {
-	throw new Exception('Attempt to add invalid media to an attachment object');
-      }
+    if( ($type != 'image' && $type != 'flash' && $type != 'music') || !$src || !$href ) {
+      throw new Exception('Attempt to add invalid media to an attachment object');
+    }
 
-    if( count($this->_media) == 5 )
-      {
-	throw new Exception('Attempt to add too many media objects to an attachment');
-      }
+    if( count($this->_media) == 5 ) {
+      throw new Exception('Attempt to add too many media objects to an attachment');
+    }
 
     $tmp = array('type'=>$type,'src'=>$src,'href'=>$href);
     $this->_media[] = $tmp;
@@ -110,15 +103,13 @@ class cgfb_post_attachment
 
   public function add_property($name,$text,$href = '')
   {
-    if( !$name || !$text )
-      {
-	throw new Exception('Attempt to add invalid property to an attachment object');
-      }
+    if( !$name || !$text ) {
+      throw new Exception('Attempt to add invalid property to an attachment object');
+    }
 
-    if( $href )
-      {
-	$text = array('text'=>$text,'href'=>$href);
-      }
+    if( $href ) {
+      $text = array('text'=>$text,'href'=>$href);
+    }
 
     $this->_props[$name] = $text;
   }
@@ -126,10 +117,9 @@ class cgfb_post_attachment
 
   public function add_data($key,$value)
   {
-    if( !$key || !$value )
-      {
-	throw new Exception('Attempt to add invalid property to an attachment object');
-      }
+    if( !$key || !$value ) {
+      throw new Exception('Attempt to add invalid property to an attachment object');
+    }
 
     $this->_assoc[$key] = $value;
   }
@@ -144,27 +134,22 @@ class cgfb_post_attachment
     if( $this->description ) $output['description'] = $this->description;
     if( $this->comments_xid ) $output['comments_xid'] = $this->comments_xid;
 
-    if( count(array_keys($this->_props)) )
-      {
-	$output['properties'] = array();
-	foreach( $this->_props as $key => $value )
-	  {
-	    $output['properties'] = array($key,$value);
-	  }
+    if( count(array_keys($this->_props)) ) {
+      $output['properties'] = array();
+      foreach( $this->_props as $key => $value ) {
+	$output['properties'] = array($key,$value);
       }
+    }
 
-    if( count($this->_media) )
-      {
-	$output['media'] = $this->_media;
-      }
+    if( count($this->_media) ) {
+      $output['media'] = $this->_media;
+    }
 
-    if( count($this->_assoc) )
-      {
-	foreach( $this->_assoc as $key => $value )
-	  {
-	    $output[$key] = $value;
-	  }
+    if( count($this->_assoc) ) {
+      foreach( $this->_assoc as $key => $value ) {
+	$output[$key] = $value;
       }
+    }
 
     return $output;
   }
