@@ -45,7 +45,7 @@ class cgfb_smarty
    */
   private static function get_preference($name)
   {
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     return $mod->GetPreference($name);
   }
 
@@ -54,7 +54,7 @@ class cgfb_smarty
    */
   private static function get_image($name)
   {
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $url = $mod->GetModuleURLPath()."/images/$name";
     return $url;
   }
@@ -102,11 +102,10 @@ class cgfb_smarty
     $res = cgfb::api($call,'GET',$params);
     if( !$res ) return;
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$res);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$res);
+      return;
+    }
 
     return $res;
   }
@@ -136,26 +135,22 @@ class cgfb_smarty
 
     $url = cgfb::get_login_url();
     $url = str_replace('&','&amp;',$url);
-    if( isset($params['urlonly']) )
-      {
-	$output = $url;
-      }
-    else
-      {
-	$params['url'] = $url;
-	if( !isset($params['image']) )
-	  {
-	    $params['image'] = self::get_image('fb_login.gif');
-	  }
-	$output = cge_tags::link_tag($params);
+    if( isset($params['urlonly']) ) {
+      $output = $url;
+    }
+    else {
+      $params['url'] = $url;
+      if( !isset($params['image']) ) {
+	$params['image'] = self::get_image('fb_login.gif');
       }
+      $output = cge_tags::link_tag($params);
+    }
 
     // handle assign
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$output);
+      return;
+    }
     return $output;
   }
 
@@ -174,26 +169,22 @@ class cgfb_smarty
 
     $url = cgfb::get_logout_url();
     $output = '';
-    if( isset($params['urlonly']) )
-      {
-	$output = $url;
-      }
-    else
-      {
-	$params['url'] = $url;
-	if( !isset($params['image']) )
-	  {
-	    $params['image'] = self::get_image('fb_logout.gif');
-	  }
-	$output = cge_tags::link_tag($params);
+    if( isset($params['urlonly']) ) {
+      $output = $url;
+    }
+    else {
+      $params['url'] = $url;
+      if( !isset($params['image']) ) {
+	$params['image'] = self::get_image('fb_logout.gif');
       }
+      $output = cge_tags::link_tag($params);
+    }
 
     // handle assign
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$output);
+      return;
+    }
     
     return $output;
   }
@@ -210,11 +201,10 @@ class cgfb_smarty
     $me = cgfb::me();
     if( !is_array($me) ) return;
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$me);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$me);
+      return;
+    }
     return $me;
   }
 
@@ -230,11 +220,10 @@ class cgfb_smarty
     $uid = cgfb::uid();
     if( !$uid ) return;
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$uid);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$uid);
+      return;
+    }
     return $uid;
   }
 
@@ -248,24 +237,22 @@ class cgfb_smarty
    */
   public static function app($params,&$smarty)
   {
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $appid = $mod->GetPreference('fb_appid');
 
     $call = $appid;
-    if( isset($params['call']) )
-      {
-	$call .= '/'.trim($params['call']);
-	unset($params['call']);
-      }
+    if( isset($params['call']) ) {
+      $call .= '/'.trim($params['call']);
+      unset($params['call']);
+    }
 
     $res = cgfb::api($call);
     if( !$res ) return;
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$res);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$res);
+      return;
+    }
 
     return $res;
   }
@@ -283,49 +270,39 @@ class cgfb_smarty
    */
   public static function comments($params,&$smarty)
   {
-    $uniqueid = 'r'.md5(cge_url::current_url());
+    $href = cge_url::current_url();
     $width = 425;
     $ncomments = 10;
     $publish = 1;
 
-    if( isset($params['uniqueid']) ) 
-      {
-	$uniqueid = trim($params['uniqueid']);
-      }
-    if( isset($params['width']) ) 
-      {
-	$width = (int)$params['width'];
-      }
-    if( isset($params['ncomments']) ) 
-      {
-	$ncomments = (int)$params['ncomments'];
-      }
-    if( isset($params['publish']) ) 
-      {
-	$publish = (int)$params['publish'];
-      }
+    if(isset($params['href'])) {
+      $href = trim($params['href']);
+    }
+    $uniqueid = 'r'.md5($href);
+    if( isset($params['uniqueid']) ) $uniqueid = trim($params['uniqueid']);
+    if( isset($params['width']) ) $width = (int)$params['width'];
+    if( isset($params['ncomments']) ) $ncomments = (int)$params['ncomments'];
+    if( isset($params['publish']) ) $publish = (int)$params['publish'];
 
-    if( $publish )
-      {
-	$publish = 'true';
-      }
-    else
-      {
-	$publish = 'false';
-      }
+    if( $publish ) {
+      $publish = 'true';
+    }
+    else {
+      $publish = 'false';
+    }
 
     $opts = array();
     if( $uniqueid ) $opts[] = 'xid="'.$uniqueid.'"';
     $opts[] = 'publish="'.$publish.'"';
     $opts[] = 'width="'.$width.'"';
     $opts[] = 'numposts="'.$ncomments.'"';
+    $opts[] = 'href"'.$href.'"';
     $output = '<fb:comments '.implode(' ',$opts).'></fb:comments>';
     
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$output);
+      return;
+    }
 
     return $output;
   }
@@ -350,83 +327,75 @@ class cgfb_smarty
     $parms = array();
     $parms['href'] = cge_url::current_url();
 
-    foreach( $params as $key => $value )
-      {
-	switch( $key )
-	  {
-	  case 'href':
-	    $parms['href'] = trim($value);
-	    break;
+    foreach( $params as $key => $value ) {
+      switch( $key ) {
+      case 'href':
+	$parms['href'] = trim($value);
+	break;
 
-	  case 'layout':
-	    $value = strtolower($value);
-	    switch( $value )
-	      {
-	      case 'standard':
-	      case 'button_count':
-	      case 'box_count':
-		$parms[$key] = $value;
-		break;
-	      }
-	    break;
+      case 'layout':
+	$value = strtolower($value);
+	switch( $value ) {
+	case 'standard':
+	case 'button_count':
+	case 'box_count':
+	  $parms[$key] = $value;
+	  break;
+	}
+	break;
 
-	  case 'show_faces':
-	    if( $value ) $value = 'true';
-	    else $value = 'false';
-	    $parms[$key] = $value;
-	    break;
+      case 'show_faces':
+	if( $value ) $value = 'true';
+	else $value = 'false';
+	$parms[$key] = $value;
+	break;
 
-	  case 'action':
-	    $value = strtolower($value);
-	    if( $value == 'like' || $value == 'recommend' )
-	      $parms[$key] = $value;
-	    break;
+      case 'action':
+	$value = strtolower($value);
+	if( $value == 'like' || $value == 'recommend' )  $parms[$key] = $value;
+	break;
 
-	  case 'width':
-	    $parms[$key] = (int)$value;
-	    break;
+      case 'width':
+	$parms[$key] = (int)$value;
+	break;
 
-	  case 'font':
-	    $value = strtolower($value);
-	    switch( $value )
-	      {
-	      case 'arial':
-	      case 'lucida grande':
-	      case 'segoe ui':
-	      case 'tahoma':
-	      case 'trebuchet ms':
-	      case 'verdana':
-		$parms[$key] = $value;
-		break;
-	      }
-	    break;
+      case 'font':
+	$value = strtolower($value);
+	switch( $value ) {
+	case 'arial':
+	case 'lucida grande':
+	case 'segoe ui':
+	case 'tahoma':
+	case 'trebuchet ms':
+	case 'verdana':
+	  $parms[$key] = $value;
+	  break;
+	}
+	break;
 
-	  case 'colorscheme':
-	    $value = strtolower($value);
-	    if( $value == 'light' || $value == 'dark' )
-	      {
-		$parms[$key] = $value;
-	      }
-	    break;
+      case 'colorscheme':
+	$value = strtolower($value);
+	if( $value == 'light' || $value == 'dark' ) {
+	  $parms[$key] = $value;
+	}
+	break;
 
-	  case 'ref':
-	    $parms[$key] = $value;
-	    break;
-	  }
+      case 'ref':
+	$parms[$key] = $value;
+	break;
       }
+    }
 
     $output = '<fb:like ';
-    foreach( $parms as $key => $value )
-      {
-	$output .= ' '.$key.'="'.$value.'"';
-      }
+    foreach( $parms as $key => $value ) {
+      $output .= ' '.$key.'="'.$value.'"';
+    }
     $output .= '></fb:like>';
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$output);
+      return;
+    }
 
     return $output;
   }
@@ -450,21 +419,18 @@ class cgfb_smarty
     unset($params['uri']);
 
     $res = null;
-    if( isset($params['as_app']) && $params['as_app'] )
-      {
-	unset($params['as_app']);
-	$res = cgfb::app_api($uri,'POST',$params);
-      }
-    else
-      {
-	$res = cgfb::api($uri,'POST',$params);
-      }
+    if( isset($params['as_app']) && $params['as_app'] ) {
+      unset($params['as_app']);
+      $res = cgfb::app_api($uri,'POST',$params);
+    }
+    else {
+      $res = cgfb::api($uri,'POST',$params);
+    }
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$res);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$res);
+      return;
+    }
 
     return $res;
   }
@@ -503,79 +469,64 @@ class cgfb_smarty
     $description = trim(strip_tags(get_parameter_value($params,'desc')));
 
     if( !$msg ) return;
-    try
-      {
-	$post = new cgfb_post($msg,$to);
+    try {
+      $post = new cgfb_post($msg,$to);
 
-	$att = null;
-	if( $name )
-	  {
-	    $att = new cgfb_post_attachment($name,$href,$caption,$description);
-	    $have_image = FALSE;
-	    foreach( $params as $key => $value )
-	      {
-		if( $key == 'xid' )
-		  {
-		    $att->comments_xid = $value;
-		    continue;
-		  }
-		else if( $key == 'images' && !$have_image )
-		  {
-		    if( is_array($value) )
-		      {
-			foreach( $value as $k => $v )
-			  {
-			    $att->add_media('image',$k,$v);
-			  }
-		      }
-		    $have_image = TRUE;
-		  }
-		else if( startswith($key,'prop') )
-		  {
-		    list($k,$v,$h) = explode(',',$value,3);
-		    if( $k && $v )
-		      {
-			$att->add_property($k,$v,$h);
-		      }
-		  }
-		else if( startswith($key,'data') )
-		  {
-		    list($k,$v) = explode(',',$value,2);
-		    $att->add_data($k,$v);
-		  }
-		else if( startswith($key,'image') && !$have_image )
-		  {
-		    list($s,$h) = explode(':::',$value,2);
-		    $att->add_media('image',$s,$h);
-		  }
-                else if( startswith($key,'action') )
-                  {
-                    list($n,$h) = explode(':::',$value,2);
-                    if( empty($h) )
-                      list($n,$h) = explode(',',$value,2);
-                    $tmp = (int)substr($key,strlen('action'));
-                    if( $tmp < 1 || $tmp > 3 ) continue;
-		    $post->add_action($n,$h);
-                  }
+      $att = null;
+      if( $name ) {
+	$att = new cgfb_post_attachment($name,$href,$caption,$description);
+	$have_image = FALSE;
+	foreach( $params as $key => $value ) {
+	  if( $key == 'xid' ) {
+	    $att->comments_xid = $value;
+	    continue;
+	  }
+	  else if( $key == 'images' && !$have_image ) {
+	    if( is_array($value) ) {
+	      foreach( $value as $k => $v ) {
+		$att->add_media('image',$k,$v);
 	      }
-
-	    $post->set_attachment($att);
+	    }
+	    $have_image = TRUE;
 	  }
-
-	$data = array_merge(array('method'=>'stream.publish'),$post->to_array());
-	$res = cgfb::rest($data);
-	if( isset($params['assign']) )
-	  {
-	    $smarty->assign($params['assign'],$res);
-	    return;
+	  else if( startswith($key,'prop') ) {
+	    list($k,$v,$h) = explode(',',$value,3);
+	    if( $k && $v ) {
+	      $att->add_property($k,$v,$h);
+	    }
 	  }
-	return $res;
+	  else if( startswith($key,'data') ) {
+	    list($k,$v) = explode(',',$value,2);
+	    $att->add_data($k,$v);
+	  }
+	  else if( startswith($key,'image') && !$have_image ) {
+	    list($s,$h) = explode(':::',$value,2);
+	    $att->add_media('image',$s,$h);
+	  }
+	  else if( startswith($key,'action') ) {
+	    list($n,$h) = explode(':::',$value,2);
+	    if( empty($h) ) list($n,$h) = explode(',',$value,2);
+	    $tmp = (int)substr($key,strlen('action'));
+	    if( $tmp < 1 || $tmp > 3 ) continue;
+	    $post->add_action($n,$h);
+	  }
+	}
+
+	$post->set_attachment($att);
       }
-    catch( Exception $e )
-      {
-	// nothing to do here.
-        die('ERROR: '.$e->getMessage());
+
+      $data = array_merge(array('method'=>'stream.publish'),$post->to_array());
+      $res = cgfb::rest($data);
+      if( isset($params['assign']) ) {
+	$smarty->assign($params['assign'],$res);
+	return;
       }
+      return $res;
+    }
+    catch( Exception $e ) {
+      // nothing to do here.
+      die('ERROR: '.$e->getMessage());
+    }
   }
 
 
@@ -595,44 +546,36 @@ class cgfb_smarty
     $msg = get_parameter_value($params,'msg');    
     if( !$msg ) return;
 
-    try
-      {
-	$obj = new cgfb_post($msg,$to);
-	$data = $obj->to_array();
-	$args = array('as_app','action1','action2','action3');
-	$argmap = array('desc'=>'description');
-	foreach( $params as $key => $value )
-	  {
-	    if( in_array($key,$args) )
-	      {
-		// translate our name to facebooks param name.
-		if( isset($argmap[$key]) )
-		  {
-		    $key = $argmap[$key];
-		  }
+    try {
+      $obj = new cgfb_post($msg,$to);
+      $data = $obj->to_array();
+      $args = array('as_app','action1','action2','action3');
+      $argmap = array('desc'=>'description');
+      foreach( $params as $key => $value ) {
+	if( in_array($key,$args) ) {
+	  // translate our name to facebooks param name.
+	  if( isset($argmap[$key]) ) $key = $argmap[$key];
 
-		// special cases for certain params
-		if( $key == 'to' )
-		  {
-		    $uri = $params['to'].'/feed';
-		    unset($params['to']);
-		    $data['uri'] = $uri;
-		    continue;
-		  }
-
-		$data[$key] = $value;
-	      }
+	  // special cases for certain params
+	  if( $key == 'to' ) {
+	    $uri = $params['to'].'/feed';
+	    unset($params['to']);
+	    $data['uri'] = $uri;
+	    continue;
 	  }
 
-	$data = array_merge(array('method'=>'stream.publish'),$data);
-	$res = cgfb::rest($data);
-      }
-    catch( Exception $e )
-      {
-	// nothing to do here.
-        die('ERROR: '.$e->getMessage());
+	  $data[$key] = $value;
+	}
       }
 
+      $data = array_merge(array('method'=>'stream.publish'),$data);
+      $res = cgfb::rest($data);
+    }
+    catch( Exception $e ) {
+      // nothing to do here.
+      die('ERROR: '.$e->getMessage());
+    }
+
     return $res;
   }
 
@@ -659,7 +602,7 @@ class cgfb_smarty
   public static function invite($params,&$smarty)
   {
     static $cnt = 0;
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $vars = array();
     $vars['as_app'] = 1;
     $vars['method'] = 'GET';
@@ -668,70 +611,65 @@ class cgfb_smarty
     $vars['action_text'] = $mod->Lang('dflt_action_text');
     $vars['border'] = 'true';
     
-    foreach( $params as $key => $value )
-      {
-	switch( $key )
-	  {
-	  case 'assign':
-	    // nothing to do here.
-	    break;
+    foreach( $params as $key => $value ) {
+      switch( $key ) {
+      case 'assign':
+	// nothing to do here.
+	break;
 
-	  case 'method':
-	    $value = strtoupper($value);
-	    if( $value == 'GET' || $value == 'POST' )
-	      {
-		$vars[$key] = trim($value);
-	      }
-	    break;
+      case 'method':
+	$value = strtoupper($value);
+	if( $value == 'GET' || $value == 'POST' ) {
+	  $vars[$key] = trim($value);
+	}
+	break;
 
-	  case 'dest_url':
-	  case 'app_name':
-	  case 'action_text':
-	  case 'exclude_ids':
-	  case 'content':
-	    $vars[$key] = trim($value);
-	    break;
+      case 'dest_url':
+      case 'app_name':
+      case 'action_text':
+      case 'exclude_ids':
+      case 'content':
+	$vars[$key] = trim($value);
+	break;
 
-	  case 'border':
-	  case 'email_invite':
-	  case 'import_external_friends':
-	  case 'condensed':
-	    $value = cge_utils::to_bool($value);
-	    $value = ($value?'true':'false');
-	    $vars[$key] = $value;
-	    break;
-	    
-	  case 'rows':
-	    $value = (int)$value;
-	    $value = max($value,3);
-	    $value = min($value,10);
-	    $vars[$key] = $value;
-	    break;
+      case 'border':
+      case 'email_invite':
+      case 'import_external_friends':
+      case 'condensed':
+	$value = cge_utils::to_bool($value);
+	$value = ($value?'true':'false');
+	$vars[$key] = $value;
+	break;
 
-	  case 'cols':
-	    $value = (int)$value;
-	    if( $value == 2 || $value == 3 || $value == 5 )
-	      {
-		$vars[$key] = $value;
-	      }
-	    break;
+      case 'rows':
+	$value = (int)$value;
+	$value = max($value,3);
+	$value = min($value,10);
+	$vars[$key] = $value;
+	break;
 
-	  case 'max':
-	    $value = (int)$value;
-	    $value = max($value,1);
-	    $value = min($value,35);
-	    $vars[$key] = $value;
-	    break;
+      case 'cols':
+	$value = (int)$value;
+	if( $value == 2 || $value == 3 || $value == 5 ) {
+	  $vars[$key] = $value;
+	}
+	break;
 
-	  case 'bypass':
-	    $value = strtolower($value);
-	    if( $value == 'step' || $value == 'skip' || $value == 'cancel' )
-	      {
-		$vars[$key] = trim($value);
-	      }
-	    break;
-	  }
+      case 'max':
+	$value = (int)$value;
+	$value = max($value,1);
+	$value = min($value,35);
+	$vars[$key] = $value;
+	break;
+
+      case 'bypass':
+	$value = strtolower($value);
+	if( $value == 'step' || $value == 'skip' || $value == 'cancel' ) {
+	  $vars[$key] = trim($value);
+	}
+	break;
       }
+    }
 
     // do final checks
     $vars['dest_url'] = cms_htmlentities($vars['dest_url']);
@@ -741,23 +679,20 @@ class cgfb_smarty
     // get the output.
     $hash = md5('invite'.$cnt++.serialize($params));
     $smarty->assign('hash',$hash);
-    foreach( $vars as $key => $value )
-      {
-	$smarty->assign($key,$value);
-      }
+    foreach( $vars as $key => $value ) {
+      $smarty->assign($key,$value);
+    }
 
     $thetemplate = $mod->GetPreference(CGFBApp::PREF_INVITE_TEMPLATE);
-    if( isset($params['template']) )
-      {
-	$thetemplate = trim($params['template']);
-      }
+    if( isset($params['template']) ) {
+      $thetemplate = trim($params['template']);
+    }
     $output = $mod->ProcessTemplateFromDatabase('invite_'.$thetemplate);
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$output);
+      return;
+    }
     return $output;
   }
 
@@ -768,31 +703,27 @@ class cgfb_smarty
   public static function init_fb($params,&$smarty)
   {
     $async = false;
-    if( isset($params['async']) )
-      {
-	$async = cge_utils::to_bool(trim($params['async']));
-      }
+    if( isset($params['async']) ) {
+      $async = cge_utils::to_bool(trim($params['async']));
+    }
 
     $output = '';
-    $mod = cge_utils::get_module('CGFBApp');
+    $mod = cge_utils::get_module(MOD_CGFBAPP);
     $appid = $mod->GetPreference('fb_appid');
     $smarty->assign('fb_appid',$appid);
-    if( $async )
-      {
-	$output = $mod->ProcessTemplateFromDatabase('fbinit_async');
-      }
-    else
-      {
-	$output = $mod->ProcessTemplateFromDatabase('fbinit_sync');
-      }
+    if( $async ) {
+      $output = $mod->ProcessTemplateFromDatabase('fbinit_async');
+    }
+    else {
+      $output = $mod->ProcessTemplateFromDatabase('fbinit_sync');
+    }
     
     if( !$output ) return;
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign(trim($params['assign']),$output);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign(trim($params['assign']),$output);
+      return;
+    }
 
     return $output;
   }
@@ -810,11 +741,10 @@ class cgfb_smarty
 
     $res = cgfb::fql($fql);
 
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$res);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$res);
+      return;
+    }
     return $res;
   }
 
@@ -825,20 +755,17 @@ class cgfb_smarty
   public static function fql_multiquery($params,&$smarty)
   {
     $q = array();
-    foreach($params as $k => $v)
-      {
-	if( startswith($k,'query') )
-	  {
-	    $q[] = $v;
-	  }
+    foreach($params as $k => $v) {
+      if( startswith($k,'query') ) {
+	$q[] = $v;
       }
+    }
 
     $res = cgfb::fql_multi($q);
-    if( isset($params['assign']) )
-      {
-	$smarty->assign($params['assign'],$res);
-	return;
-      }
+    if( isset($params['assign']) ) {
+      $smarty->assign($params['assign'],$res);
+      return;
+    }
     return $res;
   }
 } // end of class
@@ -847,4 +774,4 @@ class cgfb_smarty
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
